@@ -20,6 +20,12 @@ from portage.util.futures.retry import retry
 from portage.util.futures.executor.fork import ForkExecutor
 from . import _SUBMODULE_PATH_MAP
 
+try:
+	import gemato.openpgp
+except ImportError:
+	gemato = None
+
+
 class SyncBase:
 	'''Base Sync class for subclassing'''
 
@@ -294,6 +300,21 @@ class SyncBase:
 				loop.run_until_complete(decorated_func())
 		out.eend(0)
 
+	def _get_openpgp_env(self, openpgp_key_path=None):
+		if gemato is not None:
+			# Override global proxy setting with one provided in emerge configuration
+			if 'http_proxy' in self.spawn_kwargs['env']:
+				proxy = self.spawn_kwargs['env']['http_proxy']
+			else:
+				proxy = None
+
+			if openpgp_key_path:
+				openpgp_env = gemato.openpgp.OpenPGPEnvironment(proxy=proxy)
+			else:
+				openpgp_env = gemato.openpgp.OpenPGPSystemEnvironment(proxy=proxy)
+
+			return openpgp_env
+
 
 class NewBase(SyncBase):
 	'''Subclasses Syncbase adding a new() and runs it
